# Inject service into vue component.

Let's say we have these services:

```typescript
// Your services.

import { Injectable } from '@vert/core'

@Injectable()
class BookshelfService {
  // ...
}

@Injectable()
class UserService {
  // ...
}

export {
  BookshelfService,
  UserService
}
```

And here is our vue component:

```html
<template lang="pug">
</template>

<style lang="stylus" scoped>
</style>

<script lang="ts" src="./index.ts"></script>
```

```typescript
import Vue from 'vue'
import { Component } from '@vert/core'

import { BookshelfService, UserService } from './services'


@Component
export default class MyComponent extends Vue {
  private async getUserData () {
    
  }

  created () {
    this.getUserData()
  }

  constructor (
    private bookshelfSrv: BookshelfService,
    private userSrv: UserService
  ) {
    super()
  }
}
```
